<?php

/**
 * @file
 * Administrative functions to configure GoogleChat.
 */

/**
 * Callback for admin/settings/googlechat.
 */
function googlechat_settings_form() {
  $form = array();
  drupal_add_js(drupal_get_path('module', 'googlechat') . '/js/googlechat.admin.js', 'module', 'footer');
  $form['googlechat_notification_sound'] = array(
    '#type' => 'select',
    '#title' => t('Notification Sound'),
    '#description' => t('Play a sound notification when new chat messages arrive'),
    '#options' => array(GOOGLECHAT_SOUND_YES => 'Yes', GOOGLECHAT_SOUND_NO => 'No'),
    '#default_value' => variable_get('googlechat_notification_sound', GOOGLECHAT_SOUND_YES),
  );
  $form['googlechat_enable_emoticons'] = array(
    '#type' => 'select',
    '#title' => t('Enable Emoticons'),
    '#description' => t('When an emoticon is sent :-) it will automatically animate.'),
    '#options' => array(1 => 'Yes', 2 => 'No'),
    '#default_value' => variable_get('googlechat_enable_emoticons', 1),
  );
  $intervals = array(30, 60, 120, 180, 300, 600, 900, 1800, 2700, 3600);
  $list_count = $list_count = array(
    0 => 'unlimited',
    5 => 5,
    10 => 10,
    15 => 15,
    30 => 30,
    50 => 50,
    75 => 75,
    100 =>
    100);
  $period = drupal_map_assoc($intervals, 'format_interval');
  $form['googlechat_seconds_online'] = array(
    '#type' => 'select',
    '#title' => t('User activity'),
    '#default_value' => variable_get('googlechat_seconds_online', 900),
    '#options' => $period,
    '#description' => t('A user is considered online for this long after they have last viewed a page.'
    ));
  $form['googlechat_max_list_count'] = array(
    '#type' => 'select',
    '#title' => t('User list length'),
    '#default_value' => variable_get('googlechat_max_list_count', 10),
    '#options' => drupal_map_assoc($list_count),
    '#description' => t('Maximum number of currently online users to display.'
    ));
  $form['googlechat_buddylist_control_list'] = array(
    '#type' => 'fieldset',
    '#title' => t('GoogleChat Buddy List Control'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['googlechat_buddylist_control_list']['googlechat_rel'] = array(
    '#type' => 'radios',
    '#title' => t('Relationship method'),
    '#default_value' => variable_get('googlechat_rel', 0),
    '#options' => array(
      GOOGLECHAT_REL_ALL => t('All authenticated users'),
    ),
    '#description' => t('This determines the method for creating the chat buddylist.'),
  );
  if (module_exists('flag_friend')) {
    $form['googlechat_buddylist_control_list']['googlechat_rel']['#options'][GOOGLECHAT_REL_FF] = t('Flag Friend module');
  }
  if (module_exists('user_relationships_api')) {
    $form['googlechat_buddylist_control_list']['googlechat_rel']['#options'][GOOGLECHAT_REL_UR] = t('User Relationship module');
  }
  $form['googlechat_buddylist_control_list']['googlechat_ur_name'] = array(
    '#type' => 'textfield',
    '#title' => t('User Relationships Role Names to integrate with'),
    '#description' => t('The singular form of User Relationships Role Names (e.g. buddy, friend, coworker, spouse) separated by comma.'),
    '#default_value' => variable_get('googlechat_ur_name', NULL),
    '#autocomplete_path' => 'googlechat/ur-autocomplete',
  );
  return system_settings_form($form);
}
/**
 * Function to validate setting form.
 */
function googlechat_settings_form_validate($form, &$form_state) {
  if ($form_state['values']['googlechat_rel'] == GOOGLECHAT_REL_UR) {
    if (!$form_state['values']['googlechat_ur_name']) {
      form_set_error('drupalchat_ur_name', t('You must provide the user relationship name in the Drupal UR Settings section.'));
    }
    if ($form_state['values']['googlechat_ur_name']) {
      $array = drupal_explode_tags($form_state['values']['googlechat_ur_name']);
      $error = array();
      foreach ($array as $key) {
        $result = db_query("SELECT COUNT(*) as count FROM {user_relationship_types} WHERE name = '%s'", array($key));
        while ($row = db_fetch_object($result)) {
          if (!$row->count) {
            $error[] = $key;
          }
        }
      }
      if (!empty($error)) {
        form_set_error('drupalchat_ur_name', t('User Relationship type %type was not found.', array('%type' => drupal_implode_tags($error))));
      }
    }
  }
}
